Process raw school directory data to standard schema
Source:R/fetch_directory.R
process_directory.RdTakes raw school directory data from NH DOE and standardizes column names, types, and adds derived columns.
R/fetch_directory.R
process_directory.RdTakes raw school directory data from NH DOE and standardizes column names, types, and adds derived columns.